==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ObjectContext.h <==
// final class gnu.java.beans.decoder.ObjectContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 970c8880a89508ac gnu_java_beans_decoder_ObjectContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractObjectContext

#include "gnu/java/beans/decoder/AbstractObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_ObjectContext_H_
#define _JC_gnu_java_beans_decoder_ObjectContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$sub_refs	_jc_gnu_java_beans_decoder_ObjectContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs	_jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$refs	_jc_gnu_java_beans_decoder_ObjectContext$refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$nonrefs	_jc_gnu_java_beans_decoder_ObjectContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$object	_jc_gnu_java_beans_decoder_ObjectContext$object;

typedef const struct _jc_gnu_java_beans_decoder_ObjectContext$vmethods	_jc_gnu_java_beans_decoder_ObjectContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ObjectContext$vtable	_jc_gnu_java_beans_decoder_ObjectContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ObjectContext$vtype	_jc_gnu_java_beans_decoder_ObjectContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *);
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$_init$5cd68f4fce864f30(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ObjectContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *);
extern jboolean _jc_gnu_java_beans_decoder_ObjectContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ObjectContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *);
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *);
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ObjectContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_ObjectContext$vmethods	gnu_java_beans_decoder_ObjectContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ObjectContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ObjectContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectContext$refs {
    _jc_gnu_java_beans_decoder_ObjectContext$sub_refs	gnu_java_beans_decoder_ObjectContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs	gnu_java_beans_decoder_ObjectContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ObjectContext$object {
	_jc_gnu_java_beans_decoder_ObjectContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ObjectContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ObjectContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ObjectContext$vtype _jc_gnu_java_beans_decoder_ObjectContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ObjectContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ObjectContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ObjectContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ObjectContext.h <==
// final class gnu.java.beans.decoder.ObjectContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 970c8880a89508ac gnu_java_beans_decoder_ObjectContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractObjectContext

#include "gnu/java/beans/decoder/AbstractObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_ObjectContext_H_
#define _JC_gnu_java_beans_decoder_ObjectContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$sub_refs	_jc_gnu_java_beans_decoder_ObjectContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs	_jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$refs	_jc_gnu_java_beans_decoder_ObjectContext$refs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$nonrefs	_jc_gnu_java_beans_decoder_ObjectContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ObjectContext$object	_jc_gnu_java_beans_decoder_ObjectContext$object;

typedef const struct _jc_gnu_java_beans_decoder_ObjectContext$vmethods	_jc_gnu_java_beans_decoder_ObjectContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ObjectContext$vtable	_jc_gnu_java_beans_decoder_ObjectContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ObjectContext$vtype	_jc_gnu_java_beans_decoder_ObjectContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$_init$5cd68f4fce864f30(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ObjectContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_ObjectContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_ObjectContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_ObjectContext$method_info$subContextFailed$dac667c9783c2a33;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ObjectContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_ObjectContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ObjectContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_ObjectContext$vmethods	gnu_java_beans_decoder_ObjectContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ObjectContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ObjectContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectContext$refs {
    _jc_gnu_java_beans_decoder_ObjectContext$sub_refs	gnu_java_beans_decoder_ObjectContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ObjectContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_ObjectContext$sub_nonrefs	gnu_java_beans_decoder_ObjectContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ObjectContext$object {
	_jc_gnu_java_beans_decoder_ObjectContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ObjectContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ObjectContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ObjectContext$vtype _jc_gnu_java_beans_decoder_ObjectContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ObjectContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ObjectContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ObjectContext_H_ */
